# Secure Asses Data Insight Framework - SADIF


[![Release](https://img.shields.io/github/v/release/florestleaks/SADIF)](https://img.shields.io/github/v/release/florestleaks/SADIF)
[![Build status](https://img.shields.io/github/actions/workflow/status/florestleaks/SADIF/main.yml?branch=main)](https://github.com/florestleaks/SADIF/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/florestleaks/SADIF/graph/badge.svg?token=IE1G7T0wo0)](https://codecov.io/gh/florestleaks/SADIF)
[![Commit activity](https://img.shields.io/github/commit-activity/m/florestleaks/SADIF)](https://img.shields.io/github/commit-activity/m/florestleaks/SADIF)
[![License](https://img.shields.io/github/license/florestleaks/SADIF)](https://img.shields.io/github/license/florestleaks/SADIF)


- **Github repository**: <https://github.com/florestleaks/SADIF/>
- **Github Documentation** <https://florestleaks.github.io/SADIF/>
- **OFFICIAL Documentation** <https://forestleaks.com/SADIF/>

